%% Open instrument serial port

% Hyper-a defaults to 19200 baud at startup
s =serialport("COM8",19200,'timeout',10);

% Boost baud rate for fast transmission of binary data.
% Hyper-a will revert to 19200 baud if reset or if power is cycled
Hypera_SendCommand(s, 'baud 230400', 0);
s.BaudRate = 230400;

%% Configure instrument

% Config arguments are optional. If not declared,
% the current instrument setting is preserved
Hypera_Configure(s, 'SigExposureAvg',   1, ...
                    'RefExposureAvg',   1, ...
                    'SaveDataFiles',    false, ... % <-- Note: False indicates the Hyper-a will not save
                    'UsePump',          false, ... %           data files onboard the instrument. This           
                    'PumpFlush',        0);        %           increases measurement speed. Onboard data
                                                   %           logging is not nessesary if data are already
                                                   %           recorded using 'Hypera_CaptureSpectrum'. 
                                                   %           This setting reverts back to true after 
                                                   %           system reset or power cycle.

%% Collect Data
                                                   
% Collect 8 measurements at filter positions 1, 2, and 3.
% Plot them on the same figure to compare
FiltComparFig = figure(1);
[config{1}, dataTable{1}] = Hypera_CaptureSpectrum(s,1,8,'PlotSpectrum',FiltComparFig);
[config{2}, dataTable{2}] = Hypera_CaptureSpectrum(s,2,8,'PlotSpectrum',FiltComparFig);
[config{3}, dataTable{3}] = Hypera_CaptureSpectrum(s,3,8,'PlotSpectrum',FiltComparFig);
sgtitle('Filter Comparision')


% Abort Measurement
% use this command to break out sampling, if necessary
%
% Hypera_SendCommand(s, char(3),0); % sends Ctrl-c


%% Clean Up / Revert Settings

% Turn off tranmission of binary data during sampling
% ('serialout binary' was turned on inside HyperA_CaptureSpectrum)
Hypera_SendCommand(s, 'serialout off', 1);

% Turn data logging back on, to avoid confusion
Hypera_Configure(s,'SaveDataFiles', true);

% Optionally, switch back to 19200 baud.
% Hyper-a will revert to 19200 baud if reset or if power is cycled
Hypera_SendCommand(s, 'baud 19200', 0);
s.BaudRate = 19200;

% close serial port
s = [];


